if [ ! -f /etc/pki/nssdb/cert8.db ]
then
    /usr/bin/mkdir -p /etc/pki/nssdb
    /usr/bin/cp /etc/defaults/etc/pki/nssdb/cert8.db /etc/pki/nssdb/cert8.db
fi

if [ ! -f /etc/pki/nssdb/cert9.db ]
then
    /usr/bin/mkdir -p /etc/pki/nssdb
    /usr/bin/cp /etc/defaults/etc/pki/nssdb/cert9.db /etc/pki/nssdb/cert9.db
fi

if [ ! -f /etc/pki/nssdb/key3.db ]
then
    /usr/bin/mkdir -p /etc/pki/nssdb
    /usr/bin/cp /etc/defaults/etc/pki/nssdb/key3.db /etc/pki/nssdb/key3.db
fi

if [ ! -f /etc/pki/nssdb/key4.db ]
then
    /usr/bin/mkdir -p /etc/pki/nssdb
    /usr/bin/cp /etc/defaults/etc/pki/nssdb/key4.db /etc/pki/nssdb/key4.db
fi

if [ ! -f /etc/pki/nssdb/pkcs11.txt ]
then
    /usr/bin/mkdir -p /etc/pki/nssdb
    /usr/bin/cp /etc/defaults/etc/pki/nssdb/pkcs11.txt /etc/pki/nssdb/pkcs11.txt
fi

if [ ! -f /etc/pki/nssdb/secmod.db ]
then
    /usr/bin/mkdir -p /etc/pki/nssdb
    /usr/bin/cp /etc/defaults/etc/pki/nssdb/secmod.db /etc/pki/nssdb/secmod.db
fi

